@@ -2,7 +2,7 @@
  *  cache-file.c
  *  mod_musicindex
  *
- *  $Id: cache-file.c 934 2010-05-29 23:13:55Z varenet $
+ *  $Id: cache-file.c 983 2012-04-07 10:38:30Z varenet $
  *
  *  Created by Thibaut VARENE on Wed Feb 23 2005.
  *  Copyright (c) 2003-2007,2009-2010 Thibaut VARENE
@@ -18,7 +18,7 @@
  * Flat file cache management subsystem.
  *
  * @author Thibaut Varene
- * @version $Revision: 934 $
+ * @version $Revision: 983 $
  * @date 2003-2010
  *
  * @warning 'errno' seems not to be seen as volatile by the compiler, therefore we
@@ -220,7 +220,9 @@ static void file_cache_remove_dir(request_rec *r, DIR *cachedir, const char *con
 	struct stat	origdirstat;
 	const char 	*origdir = NULL;
 
-	fchdir(dirfd(cachedir));			/* on se place dans le repertoire de cache. XXX Pas de test, au pire fail sur readdir() */
+	if (unlikely(fchdir(dirfd(cachedir))))
+		return;		/* on se place dans le repertoire de cache */
+
 	while ((cachedirent = readdir(cachedir))) {	/* on parcourt le repertoire */
 		if (ISDOT(cachedirent->d_name))		/* We'd rather avoid trying to remove the whole filesystem... */
 			continue;
@@ -239,7 +241,7 @@ static void file_cache_remove_dir(request_rec *r, DIR *cachedir, const char *con
 							subdir = opendir(cachedirent->d_name);	/* on ouvre le vilain repertoire pour en supprimer le contenu */
 							file_cache_remove_dir(r, subdir, origdir);	/* en rappelant recursivement la fonction sur son contenu. */
 							closedir(subdir);			/* a noter que dans ce cas la il y a un test inutile, celui qui verifie si l'original existe tjrs. Mais bon. */
-							fchdir(dirfd(cachedir));		/* on retourne au repertoire precedent */
+							if (fchdir(dirfd(cachedir)));		/* on retourne au repertoire precedent */
 							rmdir(cachedirent->d_name);		/* maintenant il est vide, et on peut pas avoir d'erreur vu les tests precedants */
 						}
 						else
@@ -286,7 +288,8 @@ static void* cache_file_opendir(request_rec *r, mu_pack *const pack, const mu_co
 		return NULL;
 
 	/* Bear in mind we're chdir'd from now on. */
-	chdir((char *)(conf->cache_setup));
+	if (unlikely(chdir((char *)(conf->cache_setup))))
+		return NULL;
 
 	/* Actually check for the directory in the cache, create it if needed.
 	 * "+ 1" offset to suppress leading '/'. */
