@@ -2,7 +2,7 @@
  *  cache-mysql.c
  *  mod_musicindex
  *
- *  $Id: cache-mysql.c 955 2011-08-06 14:40:17Z varenet $
+ *  $Id: cache-mysql.c 982 2012-04-07 10:25:22Z varenet $
  *
  *  Created by Thibaut VARENE on Tue Feb 22 2005.
  *  Copyright (c) 2005,2007,2009-2010 Thibaut VARENE
@@ -49,7 +49,7 @@
  * @todo clean error handler when data corruption happens.
  *
  * @author Thibaut Varene
- * @version $Revision: 955 $
+ * @version $Revision: 982 $
  * @date 2005,2007,2009-2010
  */
 
@@ -383,7 +383,7 @@ err2:
 err1:
 	if (!mysql_params.ready)
 		mi_serror("Likely length overflow in configuration fields: "
-			  "user: %u/%u, pass: %u/%u, db: %u/%u, host: %u/%u",
+			  "user: %zu/%u, pass: %zu/%u, db: %zu/%u, host: %zu/%u",
 			  strlen(mysql_params.user), SQL_SMAX_UPD, strlen(mysql_params.pass),
 			  SQL_SMAX_UPD, strlen(mysql_params.db), SQL_SMAX_UPD,
 			  strlen(mysql_params.host), SQL_SMAX_H);
