@@ -2,11 +2,11 @@
  *  html.c
  *  mod_musicindex
  *
- *  $Id: html.c 962 2011-10-31 17:32:29Z varenet $
+ *  $Id: html.c 978 2012-03-15 20:21:24Z varenet $
  *
  *  Created by Thibaut VARENE on Thu Mar 20 2003.
  *  Copyright (c) 2003-2006 Regis BOUDIN
- *  Copyright (c) 2003-2010 Thibaut VARENE
+ *  Copyright (c) 2003-2012 Thibaut VARENE
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License version 2.1,
@@ -20,8 +20,8 @@
  *
  * @author Regis Boudin
  * @author Thibaut Varene
- * @version $Revision: 962 $
- * @date 2003-2010
+ * @version $Revision: 978 $
+ * @date 2003-2012
  *
  * That file groups all functions related to HTML and assimilated
  * generation, that is to say functions that are used to
@@ -194,7 +194,7 @@ list_songs(request_rec *r, const mu_pack *const pack, const mu_config *const con
 	ap_rputs("  </tr>\n", r);
 
 	/* init value. No chance to see the first strcmp true with that one */
-	current = "";
+	current = "///";
 	new = current;
 
 	for (q=pack->fhead; q!= NULL; q=q->next) {
@@ -349,8 +349,7 @@ list_songs(request_rec *r, const mu_pack *const pack, const mu_config *const con
 	
 	/* Do NOT show 'select all' if there's nothing to select... */
 	if (!customlist && (conf->search) && (conf->options & MI_ALLOWSTREAM))
-		ap_rvputs(r, "<input type=\"checkbox\" name=\"all\" onClick=\"for(var i=0;i<this.form.elements.length;i++){var inpt=this.form.elements[i];"
-			"var m=inpt.name.match(/-/g);if((inpt.name.substr(0,4)=='file') && (m<1)) inpt.checked=this.form.all.checked}\" />",
+		ap_rvputs(r, "<input type=\"checkbox\" name=\"all\" onclick=\"selall(this)\" />",
 			_("Select All"), " - ", NULL);
 	
 	ap_rprintf(r, "%s: %ld:%.2ld:%.2ld - %s: %ld%s%ld MB</th>\n  </tr>\n",
@@ -537,6 +536,20 @@ void send_head(request_rec *r, const mu_config *const conf)
 			"title=\"Podcast\" href=\"?action=podcast\" />\n", r);
 	}
 
+	/* bit of javascript to handle select all */
+	ap_rputs(" <script type=\"text/javascript\">\n"
+		" // <![CDATA[\n"
+		" function selall(mine) {\n"
+		" 	for(var i=0; i<mine.form.elements.length; i++) {\n"
+		"		var inpt = mine.form.elements[i];\n"
+		"		var m = inpt.name.match(/-/g);\n"
+		"		if ((inpt.name.substr(0,4) == 'file') && (m < 1)) {\n"
+		"			inpt.checked = mine.form.all.checked;\n"
+		"		}\n"
+		" 	}\n"
+		" }\n"
+		" // ]]>\n"
+		" </script>\n", r);
 
 	/* the original favicon */
 	ap_rvputs(r, " <link rel=\"shortcut icon\" href=\"", conf->directory, "/", Gfavicon, "\" />\n"
