@@ -2,11 +2,11 @@
  *  mod_musicindex.c
  *  mod_musicindex
  *
- *  $Id: mod_musicindex.c 956 2011-08-13 15:03:13Z varenet $
+ *  $Id: mod_musicindex.c 973 2012-02-16 13:43:14Z varenet $
  *
  *  Created by Regis BOUDIN on Sat Dec 28 2002.
  *  Copyright (c) 2002-2006 Regis BOUDIN
- *  Copyright (c) 2002-2005,2007-2008,2010 Thibaut VARENE
+ *  Copyright (c) 2002-2005,2007-2008,2010-2011 Thibaut VARENE
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License version 2.1,
@@ -18,11 +18,13 @@
 /**
  * @mainpage
  * @section about About
- *	mod_musicindex is an Apache module initially aimed at being a C implementation
- *	of the Perl module <a href="http://search.cpan.org/dist/Apache-MP3/">
+ *	mod_musicindex is an Apache module initially aimed at being a C alternative 
+ *	to the Perl module <a href="http://search.cpan.org/dist/Apache-MP3/">
  *	Apache::MP3</a>. It allows nice displaying of directories containing
  *	MP3, Ogg Vorbis, FLAC or MP4/AAC files, including sorting them on various
  *	fields, streaming/downloading them, constructing playlist, and searching.
+ *	It also provides features such as RSS and Podcast feeds, multiple CSS
+ *	support, and archive downloads.
  *
  * @section features Features
  *	- Allow/deny file downloading.
@@ -96,7 +98,7 @@
  *	beginning of the function, and avoid as much as possible to declare
  *	subvariables in blocks.
  *	- In any case, @b never declare new variables @b after code in a block.
- *	- Finally, special care should be bore to storage space: always declare
+ *	- Finally, special care should be borne to storage space: always declare
  *	as @e little as possible: we want the module to consume as few
  *	memory as possible. That also applies to functions return types.
  *
@@ -129,9 +131,9 @@
  * This file is the core of the module. It contains Apache's mandatory stuff.
  *
  * @author Regis Boudin
- * @version $Revision: 956 $
+ * @version $Revision: 973 $
  * @date 2002-2008
- * @date 2010
+ * @date 2010-2011
  *
  * http://httpd.apache.org/docs-2.0/developer/API.html
  * http://httpd.apache.org/dev/apidoc/
