@@ -2,7 +2,7 @@
  *  playlist-ogg.h
  *  mod_musicindex
  *
- *  $Id: playlist-vorbis.h 566 2006-02-04 01:14:20Z boudinr $
+ *  $Id: playlist-vorbis.h 742 2007-04-23 13:15:36Z varenet $
  *
  *  Created by Regis BOUDIN on Thu Jan 22 2004.
  *  Copyright (c) 2003-2004 Regis BOUDIN
@@ -20,5 +20,5 @@
 #include "mod_musicindex.h"
 
 mu_ent *make_ogg_entry(request_rec *r, apr_pool_t *pool, FILE *const in,
-	mu_ent *const head, const mu_config *const conf, mu_ent_names *const names);
+	const mu_config *const conf, mu_ent_names *const names);
 #endif
