@@ -2,11 +2,11 @@
  *  playlist.c
  *  mod_musicindex
  *
- *  $Id: playlist.c 823 2009-02-05 19:38:14Z varenet $
+ *  $Id: playlist.c 899 2009-12-04 13:55:29Z varenet $
  *
  *  Created by Thibaut VARENE on Thu Mar 20 2003.
  *  Copyright (c) 2003-2004 Regis BOUDIN
- *  Copyright (c) 2003-2008 Thibaut VARENE
+ *  Copyright (c) 2003-2009 Thibaut VARENE
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License version 2.1,
@@ -20,8 +20,8 @@
  *
  * @author Regis Boudin
  * @author Thibaut Varene
- * @version $Revision: 823 $
- * @date 2003-2008
+ * @version $Revision: 899 $
+ * @date 2003-2009
  *
  * This is where the magic takes place. Here are the functions in charge of
  * analyzing the content of the folders requested by the client, and of
@@ -88,7 +88,7 @@ static inline mu_ent *make_no_entry(request_rec *r, apr_pool_t *pool, FILE *cons
 }
 
 /**
- * Wrapper function to call the actuall cache backend.
+ * Wrapper function to call the actual cache backend.
  *
  * @param r Apache request_rec struct
  * @param pool Apache memory pool
@@ -167,8 +167,6 @@ typedef struct mu_dir {
  * @param conf Configuration of the current request
  * @param names structure containing the name of the directory
  * @param soptions the current extended options
- *
- * @return handler for the directory.
  */
 static inline void 
 musicindex_opendir(request_rec *r, mu_dir *dir, mu_pack *const pack, const mu_config *const conf,
@@ -197,8 +195,8 @@ musicindex_opendir(request_rec *r, mu_dir *dir, mu_pack *const pack, const mu_co
  * @param dir Abstract pointer to our custom directory handler
  * @param conf Module configuration (to get the current cache backend)
  *
- * @return pointer to the string of the filename, or NULL if there is nothing
- *         left to open.
+ * @return pointer to the string of the filename, @b without any trailing /,
+ *		or NULL if there is nothing left to open.
  */
 static inline const char *musicindex_readdir(mu_dir *dir, const mu_config *const conf)
 {
@@ -211,7 +209,6 @@ static inline const char *musicindex_readdir(mu_dir *dir, const mu_config *const
 			return NULL;
 		else
 			return dstruct->d_name;
-
 	}
 	else {
 		/* not all cache subsys can perform whole directory read */
@@ -226,8 +223,6 @@ static inline const char *musicindex_readdir(mu_dir *dir, const mu_config *const
  *
  * @param dir Abstract pointer to our custom directory handler
  * @param conf Module configuration (to get the current cache backend)
- *
- * @return nothing.
  */
 static inline void musicindex_closedir(mu_dir *dir, const mu_config *const conf)
 {
@@ -235,7 +230,8 @@ static inline void musicindex_closedir(mu_dir *dir, const mu_config *const conf)
 	if (dir->handled == 0)
 		closedir((DIR *)(dir->dir));
 	else
-		conf->cache->closedir(dir->dir, conf);
+		if (conf->cache->closedir)
+			conf->cache->closedir(dir->dir, conf);
 }
 
 /**
@@ -288,6 +284,10 @@ go_through_directory(request_rec *r, const mu_config *const conf, const unsigned
  * @note This function will NOT and should NEVER muck with mu_pack.fhead. This
  * should be taken care of by whoever calls it.
  *
+ * @note @a r->filename is the path to the file on the filesystem,
+ * while @a r->parsed_uri.path is the path to the file on the webserver,
+ * so no assertion can be made on their respective length
+ *
  * @param pool Pool
  * @param r Apache request_rec struct to handle log writings (debugging)
  * @param pack A pack of music entries to populate
@@ -303,39 +303,37 @@ void make_music_entry(request_rec *r, apr_pool_t *pool, mu_pack *const pack,
 {
 	mu_ent		*p = NULL;
 	register unsigned short	i;
-	char			*uri;
-
-	if (!names) {
-		/* DEV NOTE: filename is the path to the file on the filesystem,
-		while parsed_uri.path is the path to the file on the webserver,
-		so no assertion can be made on their respective length */
-		if ((strlen(r->filename) >= MAX_STRING) || (strlen(r->parsed_uri.path) >= MAX_STRING))
-			return;
-		names = apr_palloc(pool, sizeof(mu_ent_names));
-		strcpy(names->filename, r->filename);
-		strcpy(names->uri, r->parsed_uri.path);
-	}
-
-	/* place us at the end of the string for concatenation */
-	uri = names->uri + strlen(names->uri);
-
+	char		*uri;
+	
+	/* place us at the end of the string */
+	uri = r->parsed_uri.path + strlen(r->parsed_uri.path);
+	
 	while (*(--uri) != '/')
 		continue;
 
 	if (*(++uri) == '.')	/* we don't want "invisible" files to show */
 		return;
-
-	if (access(names->filename, R_OK) != 0)
+	
+	if (access(r->filename, R_OK) != 0)
 		return;
-
+	
+	if (!names) {
+		if (unlikely((strlen(r->filename) >= MAX_STRING) || (strlen(r->parsed_uri.path) >= MAX_STRING))) {
+			mi_rerror("DBG: MAX_STRING overflow on %s and/or %s - file ignored",
+				      r->filename, r->parsed_uri.path);
+			return;
+		}
+		names = apr_palloc(pool, sizeof(mu_ent_names));
+		strcpy(names->filename, r->filename);
+		strcpy(names->uri, r->parsed_uri.path);
+		/* remove trailing '/' if any */
+		if (names->filename[strlen(names->filename)-1] == '/')
+			names->filename[strlen(names->filename)-1] = '\0';
+	}
+		
 	if ((ap_is_directory(pool, names->filename))) {
 		request_rec *subreq;
 		int local_options = 0;
-		char *fn = names->filename + strlen(names->filename) - 1;
-
-		if (*fn++ != '/')
-			*fn++ = '/';
-		*fn = '\0';
 
 		uri = names->uri + strlen(names->uri) - 1;
 		if (*uri++ != '/')
@@ -343,8 +341,12 @@ void make_music_entry(request_rec *r, apr_pool_t *pool, mu_pack *const pack,
 		*uri = '\0';
 
 		if (conf->dir_per_line > 0) {
+			/* pretty listing of directories with action items */
 			subreq = ap_sub_req_lookup_uri(names->uri, r, NULL);
 
+			/* soptions contains the value passed to make_music_entry
+			   local_options contains the configuration for the subdirectory we're looking at
+			   conf->options contains the configuration for the directory that received the request, possibly modified by treat_{post,get}_args() etc */
 			soptions &= ~(MI_ALLOWFETCH|MI_ALLOWRSS);
 
 			if (subreq != NULL) {
@@ -352,7 +354,6 @@ void make_music_entry(request_rec *r, apr_pool_t *pool, mu_pack *const pack,
 				int local_rss = ((mu_config *)ap_get_module_config(subreq->per_dir_config, &musicindex_module))->rss_items;
 				ap_destroy_sub_req(subreq);
 
-				/* XXX pkoi pas soptions = local_options ? */
 				soptions |= (local_options & MI_ALLOWFETCH);
 
 				if (local_rss > 0)
@@ -363,10 +364,11 @@ void make_music_entry(request_rec *r, apr_pool_t *pool, mu_pack *const pack,
 		if (soptions & MI_RECURSIVE) {
 			/* We were asked to recurse, let's dig in */
 			mu_dir		dir_handler;
-			const char	*filename;
+			const char * restrict filename;
 			unsigned short	fn_max = MAX_STRING;
 			unsigned short	uri_max = MAX_STRING;
-
+			char * restrict fn = names->filename + strlen(names->filename);
+			
 			if (conf->dir_per_line < 0) {
 				subreq = ap_sub_req_lookup_uri(names->uri, r, NULL);
 
@@ -376,13 +378,12 @@ void make_music_entry(request_rec *r, apr_pool_t *pool, mu_pack *const pack,
 					local_options = ((mu_config *)ap_get_module_config(subreq->per_dir_config, &musicindex_module))->options;
 					ap_destroy_sub_req(subreq);
 
-					/* XXX pkoi pas soptions = local_options ? */
 					soptions |= (local_options & MI_ALLOWFETCH);
 				}
 			}
 
-			/* We remove the recursive bit at this point.
-			   XXX je comprends pas bien pkoi on | conf->options plutot que soptions */
+			/* We remove the recursive bit at this point. It will be reinstated
+			   if it's present in conf->options, e.g. when searching */
 			soptions &= ((~(MI_RECURSIVE)) | (conf->options));
 
 			if (go_through_directory(r, conf, local_options) == FALSE)
@@ -393,15 +394,23 @@ void make_music_entry(request_rec *r, apr_pool_t *pool, mu_pack *const pack,
 			if (NULL == dir_handler.dir)
 				return;
 
+			/* up to this point, names->filename doesn't have trailing '/' */
+			
+			/* make sure we insert a trailing slash at this point */
+			*fn++ = '/';
+			*fn = '\0';
+			
 			/* DEV NOTE: keep in mind that uri and fn both points to
 			the end of their "names->*" counterpart */
 			fn_max -= strlen(names->filename);
 			uri_max -= strlen(names->uri);
 
+			/* if a cache backend can provide full listings (during opendir()) it will return NULL
+			 * here. Otherwise, it will provide filenames "a la readdir()" for each file that's
+			 * missing in cache */
 			while ((filename = musicindex_readdir(&dir_handler, conf))) {
-				/* Before doing some strcpy, check there is
-				   enough space... */
-				if ((strlen(filename) >= fn_max) || (strlen(filename) >= uri_max))
+				/* Before doing some strcpy, check we want the file and there is enough space... */
+				if ((filename[0] == '.') || (strlen(filename) >= fn_max) || (strlen(filename) >= uri_max))
 					continue;
 				strcpy(fn, filename);
 				strcpy(uri, filename);
@@ -455,16 +464,9 @@ void make_music_entry(request_rec *r, apr_pool_t *pool, mu_pack *const pack,
 	   as it is an abuse to use these EF_ALLOW flags anyway: nothing like that
 	   will be cached, as the setting may change while the cache info may still
 	   be valid. */
-	if (soptions & MI_ALLOWSTREAM)
-		p->flags |= EF_ALLOWSTREAM;
-	if (soptions & MI_ALLOWDWNLD)
-		p->flags |= EF_ALLOWDWNLD;
-	if (soptions & MI_ALLOWTARBALL)
-		p->flags |= EF_ALLOWTARBALL;
-	if (soptions & MI_ALLOWRSS)
-		p->flags |= EF_ALLOWRSS;
+	P_FLAGS_OPTIONS(p, soptions);
 	if ((soptions & MI_CUSTOM) == 0)
-		p->file += strlen(r->parsed_uri.path);  /* remove the path before the filename except for custom playlists */
+		p->file += strlen(r->parsed_uri.path);  /* offset the path before the filename relative to request current dir, except for custom playlists */
 	if (conf->options & MI_TARBALL)	/* if the user asked for a tarball, we're going to need the absolute path to access the file */
 		p->filename = apr_pstrdup(pool, names->filename);
 
@@ -478,7 +480,7 @@ void make_music_entry(request_rec *r, apr_pool_t *pool, mu_pack *const pack,
 		p->title = p->filename;
 #else
 		/* Copy the name removing file extension (if any) and changing '_' to ' ' */
-		char *const stitle = apr_pstrndup(pool, p->filename,
+		char *const restrict stitle = apr_pstrndup(pool, p->filename,
 					((p->filetype >= 0) && strrchr(p->filename, '.')) ?	/* only strip ext if !dir */
 					(strrchr(p->filename, '.') - p->filename) : /* <=> strlen(p->file) - strlen(strrchr(p->file, '.')) */
 					strlen(p->filename));
@@ -486,15 +488,20 @@ void make_music_entry(request_rec *r, apr_pool_t *pool, mu_pack *const pack,
 		for (i=0; stitle[i]; i++)
 			if (stitle[i] == '_')
 				stitle[i] = ' ';
-		
+
 		/* Remove trailing '/' (directories) */
 		if (stitle[--i] == '/')
 			stitle[i] = '\0';
-			
+
 		p->title = stitle; 
 #endif	/* NO_TITLE_STRIP */
 	}
-
+	
+	/* We put that here for cache backends which need to "see" directories;
+	 * and it's faster to retrieve p->title than to process it again. */
+	if (conf->cache && (!(p->flags & EF_INCACHE)) && likely((!(conf->options & MI_QUICKPL)) && conf->cache->write))
+		conf->cache->write(r, p, conf, names);
+	
 	/* Entry is a directory, don't go further */
 	if (p->filetype < 0) {
 		pack->dirnb++;
@@ -502,18 +509,10 @@ void make_music_entry(request_rec *r, apr_pool_t *pool, mu_pack *const pack,
 		return;
 	}
 
-	/* We put that here so that we do not create cache files for unhandled file types,
-	 * and it's faster to retrieve p->title than to process it again. */
-	if (conf->cache && (!(p->flags & EF_INCACHE)) && likely((!(conf->options & MI_QUICKPL)) && conf->cache->write))
-		conf->cache->write(r, p, conf, names);
-
-	/* sum the total size of the files in the pack */
-	pack->fsize += p->size;
-
 	/* Here we go if we have an ongoing search request, and the file we're
 	 * looking at wasn't found in the cache. We then fall back to a basic strcasestr()
 	 * check, returning only the entries matching the search criteria */
-	if ((conf->search) && ((soptions & MI_CUSTOM) == 0)) {
+	if (unlikely((conf->search) && ((soptions & MI_CUSTOM) == 0))) {
 		const char *const file = names->uri + strlen(r->parsed_uri.path);
 		if ((ap_strcasestr(file, conf->search))				||
 			(p->artist && (ap_strcasestr(p->artist, conf->search)))	||
@@ -524,6 +523,8 @@ void make_music_entry(request_rec *r, apr_pool_t *pool, mu_pack *const pack,
 			return;	/* skip if there isn't */
 	}
 
+	/* sum the total size and number of files in the pack */
+	pack->fsize += p->size;
 	pack->filenb++;
 	pack->head = p;
 	return;
